EntityGraphDevtoolsChangeCategory enum

Inheritance
Available extensions

Values

entity → const EntityGraphDevtoolsChangeCategory
const EntityGraphDevtoolsChangeCategory('entity')
patch → const EntityGraphDevtoolsChangeCategory
const EntityGraphDevtoolsChangeCategory('patch')
entityState → const EntityGraphDevtoolsChangeCategory
const EntityGraphDevtoolsChangeCategory('entity-state')
sync → const EntityGraphDevtoolsChangeCategory
const EntityGraphDevtoolsChangeCategory('sync')
list → const EntityGraphDevtoolsChangeCategory
const EntityGraphDevtoolsChangeCategory('list')
store → const EntityGraphDevtoolsChangeCategory
const EntityGraphDevtoolsChangeCategory('store')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EntityGraphDevtoolsChangeCategory>
A constant List of the values in this enum, in order of their declaration.