EntityGraphDevtoolsCommand class final

Store-scoped command envelope used by local and VM-service transports.

Inheritance

Constructors

EntityGraphDevtoolsCommand({required String storeId, required String controllerId, required String requestId, required EntityGraphDevtoolsCommandName command, Object? payload})
const

Properties

command EntityGraphDevtoolsCommandName
final
controllerId String
final
hashCode int
The hash code for this object.
no setterinherited
payload Object?
final
protocol String
no setterinherited
requestId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeId String
finalinherited
version int
no setterinherited

Methods

envelopeJson() Map<String, Object?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited