EntityGraphDevtoolsCommandName enum

Inheritance
Available extensions

Values

getCapabilities → const EntityGraphDevtoolsCommandName
const EntityGraphDevtoolsCommandName('get-capabilities')
getSnapshot → const EntityGraphDevtoolsCommandName
const EntityGraphDevtoolsCommandName('get-snapshot')
getHistory → const EntityGraphDevtoolsCommandName
const EntityGraphDevtoolsCommandName('get-history')
getHistoryStatus → const EntityGraphDevtoolsCommandName
const EntityGraphDevtoolsCommandName('get-history-status')
getEntityRecords → const EntityGraphDevtoolsCommandName
const EntityGraphDevtoolsCommandName('get-entity-records')
getViews → const EntityGraphDevtoolsCommandName
const EntityGraphDevtoolsCommandName('get-views')
getRelationships → const EntityGraphDevtoolsCommandName
const EntityGraphDevtoolsCommandName('get-relationships')
previewEntityPatch → const EntityGraphDevtoolsCommandName
const EntityGraphDevtoolsCommandName('preview-entity-patch')
restoreEntityPreview → const EntityGraphDevtoolsCommandName
const EntityGraphDevtoolsCommandName('restore-entity-preview')
getTimeTravelStatus → const EntityGraphDevtoolsCommandName
const EntityGraphDevtoolsCommandName('get-time-travel-status')
rewind → const EntityGraphDevtoolsCommandName
const EntityGraphDevtoolsCommandName('rewind')
returnToLive → const EntityGraphDevtoolsCommandName
const EntityGraphDevtoolsCommandName('return-to-live')
inspectHistoryImport → const EntityGraphDevtoolsCommandName
const EntityGraphDevtoolsCommandName('inspect-history-import')
cancelHistoryImport → const EntityGraphDevtoolsCommandName
const EntityGraphDevtoolsCommandName('cancel-history-import')
confirmHistoryImport → const EntityGraphDevtoolsCommandName
const EntityGraphDevtoolsCommandName('confirm-history-import')
clearHistory → const EntityGraphDevtoolsCommandName
const EntityGraphDevtoolsCommandName('clear-history')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EntityGraphDevtoolsCommandName>
A constant List of the values in this enum, in order of their declaration.