isDisposed property
bool
get
isDisposed
Whether the final binding has detached and released this controller.
Implementation
bool get isDisposed => _disposing || _disposed;
Whether the final binding has detached and released this controller.
bool get isDisposed => _disposing || _disposed;