EntityGraphDevtoolsCounts class final

Aggregate graph metrics captured at one completed publication boundary.

Constructors

EntityGraphDevtoolsCounts({required int entityTypes, required int entities, required int patchedEntities, required int entityStates, required int syncMetadata, required int lists, required int listMemberships, required int fetching, required int stale, required int errors})
const

Properties

entities int
final
entityStates int
final
entityTypes int
final
errors int
final
fetching int
final
hashCode int
The hash code for this object.
no setterinherited
listMemberships int
final
lists int
final
patchedEntities int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stale int
final
syncMetadata int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited