EntityGraphDevtoolsDiagnosticEvent class final

Inheritance

Constructors

EntityGraphDevtoolsDiagnosticEvent({required String storeId, required int sequence, required String eventId, required String correlationId, required String observedAt, required String message, required EntityGraphDevtoolsSnapshotReference snapshot})
const

Properties

code String
no setter
correlationId String
finalinherited
eventId String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
final
observedAt String
finalinherited
protocol String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence int
finalinherited
snapshot EntityGraphDevtoolsSnapshotReference
final
storeId String
finalinherited
type String
no setteroverride
version int
no setterinherited

Methods

envelopeJson() Map<String, Object?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
payloadJson() Map<String, Object?>
override
toJson() Map<String, Object?>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited