EntityGraphDevtoolsEntityDirtyReason class final

Constructors

EntityGraphDevtoolsEntityDirtyReason({required EntityGraphDevtoolsDirtyReasonKind kind, required String? field, required EntityGraphDevtoolsDirtyChange change})
const

Properties

change EntityGraphDevtoolsDirtyChange
final
field String?
final
hashCode int
The hash code for this object.
no setterinherited
kind EntityGraphDevtoolsDirtyReasonKind
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited