EntityGraphDevtoolsEntityRecordsSnapshot class final

Inheritance

Constructors

EntityGraphDevtoolsEntityRecordsSnapshot({required String storeId, required String capturedAt, required Iterable<EntityGraphDevtoolsEntityRecord> entityRecords})

Properties

capturedAt String
final
entityRecords List<EntityGraphDevtoolsEntityRecord>
final
hashCode int
The hash code for this object.
no setterinherited
protocol String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeId String
finalinherited
version int
no setterinherited

Methods

envelopeJson() Map<String, Object?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited