EntityGraphDevtoolsEntityState class final
Constructors
- EntityGraphDevtoolsEntityState({required bool isFetching, required String? lastFetchedAt, required bool stale, required EntityGraphDevtoolsEntityError? error})
-
const
Properties
- error → EntityGraphDevtoolsEntityError?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFetching → bool
-
final
- lastFetchedAt → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stale → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited