EntityGraphDevtoolsEnvelope class abstract base

Base for every store-scoped v1 envelope.

Implementers

Constructors

EntityGraphDevtoolsEnvelope({required String storeId})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
protocol String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeId String
final
version int
no setter

Methods

envelopeJson() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited