EntityGraphDevtoolsExpiredHistoryReceipt class final

Inheritance

Constructors

EntityGraphDevtoolsExpiredHistoryReceipt({required int cursor, required EntityGraphDevtoolsExpiredHistoryReason reason, required int? oldestCursor, required int? newestCursor, required int? latestCursor, EntityGraphDevtoolsSnapshotUnavailableReason? unavailableReason})
const

Properties

cursor int
final
hashCode int
The hash code for this object.
no setterinherited
latestCursor int?
final
newestCursor int?
final
oldestCursor int?
final
reason EntityGraphDevtoolsExpiredHistoryReason
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unavailableReason EntityGraphDevtoolsSnapshotUnavailableReason?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited