EntityGraphDevtoolsFeature enum

Inheritance
Available extensions

Values

semanticEvents → const EntityGraphDevtoolsFeature
const EntityGraphDevtoolsFeature('semantic-events')
diagnosticEvents → const EntityGraphDevtoolsFeature
const EntityGraphDevtoolsFeature('diagnostic-events')
boundedHistory → const EntityGraphDevtoolsFeature
const EntityGraphDevtoolsFeature('bounded-history')
multiClient → const EntityGraphDevtoolsFeature
const EntityGraphDevtoolsFeature('multi-client')
multiStore → const EntityGraphDevtoolsFeature
const EntityGraphDevtoolsFeature('multi-store')
entityInspection → const EntityGraphDevtoolsFeature
const EntityGraphDevtoolsFeature('entity-inspection')
viewInspection → const EntityGraphDevtoolsFeature
const EntityGraphDevtoolsFeature('view-inspection')
relationshipInspection → const EntityGraphDevtoolsFeature
const EntityGraphDevtoolsFeature('relationship-inspection')
localPreview → const EntityGraphDevtoolsFeature
const EntityGraphDevtoolsFeature('local-preview')
snapshotHistory → const EntityGraphDevtoolsFeature
const EntityGraphDevtoolsFeature('snapshot-history')
timeTravel → const EntityGraphDevtoolsFeature
const EntityGraphDevtoolsFeature('time-travel')
historyImport → const EntityGraphDevtoolsFeature
const EntityGraphDevtoolsFeature('history-import')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EntityGraphDevtoolsFeature>
A constant List of the values in this enum, in order of their declaration.