EntityGraphDevtoolsGraphData class final

The five graph-owned data structures retained by one history snapshot.

Constructors

EntityGraphDevtoolsGraphData({required Map<String, Object?> entities, required Map<String, Object?> patches, required Map<String, Object?> entityStates, required Map<String, Object?> syncMetadata, required Map<String, Object?> lists})

Properties

entities Map<String, Object?>
final
entityStates Map<String, Object?>
final
hashCode int
The hash code for this object.
no setterinherited
lists Map<String, Object?>
final
patches Map<String, Object?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syncMetadata Map<String, Object?>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited