EntityGraphDevtoolsHistoryImportInspectionRejectionReason enum

Inheritance
  • Object
  • Enum
  • EntityGraphDevtoolsHistoryImportInspectionRejectionReason
Available extensions

Values

invalidEnvelope → const EntityGraphDevtoolsHistoryImportInspectionRejectionReason
const EntityGraphDevtoolsHistoryImportInspectionRejectionReason('invalid-envelope')
wrongStore → const EntityGraphDevtoolsHistoryImportInspectionRejectionReason
const EntityGraphDevtoolsHistoryImportInspectionRejectionReason('wrong-store')
unsupportedVersion → const EntityGraphDevtoolsHistoryImportInspectionRejectionReason
const EntityGraphDevtoolsHistoryImportInspectionRejectionReason('unsupported-version')
snapshotLimitExceeded → const EntityGraphDevtoolsHistoryImportInspectionRejectionReason
const EntityGraphDevtoolsHistoryImportInspectionRejectionReason('snapshot-limit-exceeded')
byteLimitExceeded → const EntityGraphDevtoolsHistoryImportInspectionRejectionReason
const EntityGraphDevtoolsHistoryImportInspectionRejectionReason('byte-limit-exceeded')
candidatePending → const EntityGraphDevtoolsHistoryImportInspectionRejectionReason
const EntityGraphDevtoolsHistoryImportInspectionRejectionReason('candidate-pending')
timeTravelUnavailable → const EntityGraphDevtoolsHistoryImportInspectionRejectionReason
const EntityGraphDevtoolsHistoryImportInspectionRejectionReason('time-travel-unavailable')
disposed → const EntityGraphDevtoolsHistoryImportInspectionRejectionReason
const EntityGraphDevtoolsHistoryImportInspectionRejectionReason('disposed')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EntityGraphDevtoolsHistoryImportInspectionRejectionReason>
A constant List of the values in this enum, in order of their declaration.