EntityGraphDevtoolsHistoryImportRestoreReceipt class final

Inheritance

Constructors

EntityGraphDevtoolsHistoryImportRestoreReceipt({required String candidateId, required int cursor, required int? previousCursor, required EntityGraphDevtoolsSnapshotSource? previousSource, required String changedAt})
const

Properties

candidateId String
final
changedAt String
final
cursor int
final
hashCode int
The hash code for this object.
no setterinherited
previousCursor int?
final
previousSource EntityGraphDevtoolsSnapshotSource?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited