EntityGraphDevtoolsHistoryStatus class final

Constructors

EntityGraphDevtoolsHistoryStatus({required int retainedEvents, required int retainedBytes, required int eventLimit, required int byteLimit, required int? oldestSequence, required int? newestSequence})
const

Properties

byteLimit int
final
eventLimit int
final
hashCode int
The hash code for this object.
no setterinherited
newestSequence int?
final
oldestSequence int?
final
retainedBytes int
final
retainedEvents int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited