EntityGraphDevtoolsPreviewAppliedReceipt class final

Constructors

EntityGraphDevtoolsPreviewAppliedReceipt({required String previewId, required EntityGraphDevtoolsViewMembership entity, required Object? priorPatch, required Object? previewPatch, required Object? appliedPatch, required int baselineRevision, required int previewRevision, required String appliedAt})
const

Properties

appliedAt String
final
appliedPatch Object?
final
baselineRevision int
final
entity EntityGraphDevtoolsViewMembership
final
hashCode int
The hash code for this object.
no setterinherited
previewId String
final
previewPatch Object?
final
previewRevision int
final
priorPatch Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited