EntityGraphDevtoolsPreviewConflictReceipt class final

Inheritance

Constructors

EntityGraphDevtoolsPreviewConflictReceipt({required String previewId, required int expectedRevision, required int observedRevision, required Object? currentPatch, required Object? priorPatch})
const

Properties

currentPatch Object?
final
expectedRevision int
final
hashCode int
The hash code for this object.
no setterinherited
observedRevision int
final
previewId String
finalinherited
priorPatch Object?
final
reason String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited