EntityGraphDevtoolsProtocolErrorCode enum

Inheritance
  • Object
  • Enum
  • EntityGraphDevtoolsProtocolErrorCode
Available extensions

Values

invalidEnvelope → const EntityGraphDevtoolsProtocolErrorCode
const EntityGraphDevtoolsProtocolErrorCode('invalid-envelope')
invalidPayload → const EntityGraphDevtoolsProtocolErrorCode
const EntityGraphDevtoolsProtocolErrorCode('invalid-payload')
unsupportedVersion → const EntityGraphDevtoolsProtocolErrorCode
const EntityGraphDevtoolsProtocolErrorCode('unsupported-version')
wrongStore → const EntityGraphDevtoolsProtocolErrorCode
const EntityGraphDevtoolsProtocolErrorCode('wrong-store')
staleController → const EntityGraphDevtoolsProtocolErrorCode
const EntityGraphDevtoolsProtocolErrorCode('stale-controller')
unsupportedCommand → const EntityGraphDevtoolsProtocolErrorCode
const EntityGraphDevtoolsProtocolErrorCode('unsupported-command')
entityNotFound → const EntityGraphDevtoolsProtocolErrorCode
const EntityGraphDevtoolsProtocolErrorCode('entity-not-found')
previewAlreadyActive → const EntityGraphDevtoolsProtocolErrorCode
const EntityGraphDevtoolsProtocolErrorCode('preview-already-active')
previewNotFound → const EntityGraphDevtoolsProtocolErrorCode
const EntityGraphDevtoolsProtocolErrorCode('preview-not-found')
snapshotNotFound → const EntityGraphDevtoolsProtocolErrorCode
const EntityGraphDevtoolsProtocolErrorCode('snapshot-not-found')
timeTravelUnavailable → const EntityGraphDevtoolsProtocolErrorCode
const EntityGraphDevtoolsProtocolErrorCode('time-travel-unavailable')
timeTravelActive → const EntityGraphDevtoolsProtocolErrorCode
const EntityGraphDevtoolsProtocolErrorCode('time-travel-active')
notRewound → const EntityGraphDevtoolsProtocolErrorCode
const EntityGraphDevtoolsProtocolErrorCode('not-rewound')
restoreFailed → const EntityGraphDevtoolsProtocolErrorCode
const EntityGraphDevtoolsProtocolErrorCode('restore-failed')
confirmationRequired → const EntityGraphDevtoolsProtocolErrorCode
const EntityGraphDevtoolsProtocolErrorCode('confirmation-required')
transportLimitExceeded → const EntityGraphDevtoolsProtocolErrorCode
const EntityGraphDevtoolsProtocolErrorCode('transport-limit-exceeded')
disposed → const EntityGraphDevtoolsProtocolErrorCode
const EntityGraphDevtoolsProtocolErrorCode('disposed')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EntityGraphDevtoolsProtocolErrorCode>
A constant List of the values in this enum, in order of their declaration.