EntityGraphDevtoolsRelationship class final

Properties

cardinality EntityGraphDevtoolsRelationshipCardinality
final
direction EntityGraphDevtoolsRelationshipDirection
final
hashCode int
The hash code for this object.
no setterinherited
relation String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source EntityGraphDevtoolsRelationshipEndpoint
final
status EntityGraphDevtoolsRelationshipStatus
final
target EntityGraphDevtoolsRelationshipEndpoint
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited