EntityGraphDevtoolsRelationshipsSnapshot class final
- Inheritance
-
- Object
- EntityGraphDevtoolsEnvelope
- EntityGraphDevtoolsRelationshipsSnapshot
Constructors
-
EntityGraphDevtoolsRelationshipsSnapshot({required String storeId, required String capturedAt, required Iterable<
EntityGraphDevtoolsRelationship> relationships})
Properties
- capturedAt → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- protocol → String
-
no setterinherited
-
relationships
→ List<
EntityGraphDevtoolsRelationship> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storeId → String
-
finalinherited
- version → int
-
no setterinherited
Methods
-
envelopeJson(
) → Map< String, Object?> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited