EntityGraphDevtoolsRetainedSnapshotReference class final

Inheritance

Constructors

EntityGraphDevtoolsRetainedSnapshotReference({required int cursor, required String capturedAt, required int? eventSequence, required int bytes, String? label})
const

Properties

bytes int
final
capturedAt String
finalinherited
cursor int
finalinherited
eventSequence int?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
label String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

baseJson() Map<String, Object?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited