EntityGraphDevtoolsStoreDescriptor class final

One active graph advertised by the isolate-wide VM-service registry.

Constructors

EntityGraphDevtoolsStoreDescriptor({required String storeId, required String controllerId, required EntityGraphDevtoolsCapabilities capabilities})
const

Properties

capabilities EntityGraphDevtoolsCapabilities
final
controllerId String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited