EntityGraphDevtoolsStoreRegistry class final
Versioned discovery result for every active graph in one isolate.
Constructors
-
EntityGraphDevtoolsStoreRegistry({required String capturedAt, required Iterable<
EntityGraphDevtoolsStoreDescriptor> stores})
Properties
- capturedAt → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- protocol → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stores
→ List<
EntityGraphDevtoolsStoreDescriptor> -
final
- version → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited