EntityGraphDevtoolsSuccessResult class final

Successful command result. result must already be JSON-compatible when this envelope crosses a serialized transport.

Inheritance

Constructors

EntityGraphDevtoolsSuccessResult({required String storeId, required String requestId, required Object? result})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
ok bool
no setteroverride
protocol String
no setterinherited
requestId String
finalinherited
result Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeId String
finalinherited
version int
no setterinherited

Methods

envelopeJson() Map<String, Object?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited