EntityGraphDevtoolsSyncState class final

Constructors

EntityGraphDevtoolsSyncState({required bool synced, required EntityGraphDevtoolsSyncOrigin origin, required String? updatedAt})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
origin EntityGraphDevtoolsSyncOrigin
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
synced bool
final
updatedAt String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited