EntityGraphDevtoolsValueContext class final

Context supplied to a host-owned value redactor before retention or serialization. fieldPath members are strings or integer indexes.

Constructors

EntityGraphDevtoolsValueContext({required String storeId, required EntityGraphDevtoolsChangeCategory category, required String key, required String? id, required Iterable<Object> fieldPath, required EntityGraphDevtoolsValueSide side, required EntityGraphDevtoolsValueDestination destination})

Properties

category EntityGraphDevtoolsChangeCategory
final
destination EntityGraphDevtoolsValueDestination
final
fieldPath List<Object>
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
key String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
side EntityGraphDevtoolsValueSide
final
storeId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited