EntityGraphDevtoolsValueState enum

Inheritance
Available extensions

Values

hiddenByPolicy → const EntityGraphDevtoolsValueState
const EntityGraphDevtoolsValueState('hidden-by-policy')
included → const EntityGraphDevtoolsValueState
const EntityGraphDevtoolsValueState('included')
redacted → const EntityGraphDevtoolsValueState
const EntityGraphDevtoolsValueState('redacted')
redactionError → const EntityGraphDevtoolsValueState
const EntityGraphDevtoolsValueState('redaction-error')
truncated → const EntityGraphDevtoolsValueState
const EntityGraphDevtoolsValueState('truncated')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EntityGraphDevtoolsValueState>
A constant List of the values in this enum, in order of their declaration.