EntityGraphDevtoolsViewDefinition class final

Constructors

EntityGraphDevtoolsViewDefinition({required String viewId, required String label, required EntityGraphDevtoolsViewKind kind, required String entityType, String? queryKey})
const

Properties

entityType String
final
hashCode int
The hash code for this object.
no setterinherited
kind EntityGraphDevtoolsViewKind
final
label String
final
queryKey String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited