EntityGraphDevtoolsViewEvent class final

Inheritance

Constructors

EntityGraphDevtoolsViewEvent({required String storeId, required int sequence, required String eventId, required String correlationId, required String observedAt, required EntityGraphDevtoolsViewEventState state, required String viewId, required int membershipCount})
const

Properties

correlationId String
finalinherited
eventId String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
membershipCount int
final
observedAt String
finalinherited
protocol String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence int
finalinherited
state EntityGraphDevtoolsViewEventState
final
storeId String
finalinherited
type String
no setteroverride
version int
no setterinherited
viewId String
final

Methods

envelopeJson() Map<String, Object?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
payloadJson() Map<String, Object?>
override
toJson() Map<String, Object?>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited