EntityGraphDevtoolsViewListStats class final

Constructors

EntityGraphDevtoolsViewListStats({required int visibleCount, required int graphCount, required int? total, required bool isFetching, required bool isFetchingMore, required bool stale, required bool hasNextPage, required bool hasPreviousPage})
const

Properties

graphCount int
final
hashCode int
The hash code for this object.
no setterinherited
hasNextPage bool
final
hasPreviousPage bool
final
isFetching bool
final
isFetchingMore bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stale bool
final
total int?
final
visibleCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited