EntityGraphDevtoolsVmService class abstract final

Isolate-wide, versioned VM-service surface used by Flutter DevTools.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

activeStoreIds List<String>
Active store identities advertised by listStoresMethod.
no setter
isAvailable bool
VM service extensions are absent from product-mode isolates.
no setter
isRegistered bool
Whether this isolate has registered the package-owned RPC methods.
no setter

Constants

commandMethod → const String
eventKind → const String
listStoresMethod → const String
requestBytesLimit → const int
responseBytesLimit → const int