EntityGraphDevtoolsBinding class final
Reference-counted attachment to the controller for one EntityGraph.
Properties
- controller → EntityGraphDevtoolsController?
-
Shared controller, or
nullfor a disabled binding.final - enabled → bool
-
Whether this binding retained a controller reference.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDetached → bool
-
Whether this binding has released its reference.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
detach(
) → void - Release this binding. Multiple calls release one reference at most.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
attach(
EntityGraph graph, {bool enabled = true, String? storeId, EntityGraphDevtoolsValuePolicy valuePolicy = const EntityGraphDevtoolsValuePolicy.metadataOnly(), EntityGraphIR? schema, bool vmServiceEnabled = _vmServiceAvailable, int? historyLimit, int? historyBytesLimit, int? eventBytesLimit, int? snapshotLimit, int? snapshotBytesLimit}) → EntityGraphDevtoolsBinding -
Attach development tooling to
graph. -
controllerFor(
EntityGraph graph) → EntityGraphDevtoolsController? - Return the active controller without changing its lifetime.