EntityGraphDevtoolsChange class final
One semantic change inside a completed graph publication.
Constructors
- EntityGraphDevtoolsChange({required EntityGraphDevtoolsChangeCategory category, required EntityGraphDevtoolsChangeAction action, required String key, required EntityGraphDevtoolsValueState valueState, String? id, int? beforeCount, int? afterCount, Object? before, Object? after})
-
const
Properties
- action → EntityGraphDevtoolsChangeAction
-
final
- after → Object?
-
Omitted from serialized output under the metadata-only policy.
final
- afterCount → int?
-
final
- before → Object?
-
Omitted from serialized output under the metadata-only policy.
final
- beforeCount → int?
-
final
- category → EntityGraphDevtoolsChangeCategory
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- key → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valueState → EntityGraphDevtoolsValueState
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited