EntityGraphDevtoolsEntityRecord class final
Constructors
-
EntityGraphDevtoolsEntityRecord({required String key, required String type, required String id, required EntityGraphDevtoolsEntityPresence presence, required Object? canonical, required Object? patch, required Object? merged, required bool dirty, required Iterable<
EntityGraphDevtoolsEntityDirtyReason> dirtyReasons, required EntityGraphDevtoolsEntityState entityState, required EntityGraphDevtoolsSyncState sync, required int revision, required Iterable<String> viewIds})
Properties
- canonical → Object?
-
final
- dirty → bool
-
final
-
dirtyReasons
→ List<
EntityGraphDevtoolsEntityDirtyReason> -
final
- entityState → EntityGraphDevtoolsEntityState
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- key → String
-
final
- merged → Object?
-
final
- patch → Object?
-
final
- presence → EntityGraphDevtoolsEntityPresence
-
final
- revision → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sync → EntityGraphDevtoolsSyncState
-
final
- type → String
-
final
-
viewIds
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited