Base fields shared by every retained or streamed semantic event.
- Inheritance
-
- Object
- EntityGraphDevtoolsEnvelope
- EntityGraphDevtoolsEvent
- Implementers
Constructors
Properties
- correlationId → String
-
final
- eventId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- observedAt → String
-
final
- protocol → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequence → int
-
final
- storeId → String
-
finalinherited
- type → String
-
no setter
- version → int
-
no setterinherited
Methods
-
envelopeJson(
) → Map< String, Object?> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
payloadJson(
) → Map< String, Object?> -
toJson(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited