EntityGraphDevtoolsHistoryImportEnvelope class final
- Inheritance
-
- Object
- EntityGraphDevtoolsEnvelope
- EntityGraphDevtoolsHistoryImportEnvelope
Constructors
-
EntityGraphDevtoolsHistoryImportEnvelope({required String storeId, required String exportedAt, required Iterable<
EntityGraphDevtoolsHistoryImportSnapshot> snapshots})
Properties
- exportedAt → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- protocol → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
snapshots
→ List<
EntityGraphDevtoolsHistoryImportSnapshot> -
final
- storeId → String
-
finalinherited
- version → int
-
no setterinherited
Methods
-
envelopeJson(
) → Map< String, Object?> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited