EntityGraphDevtoolsHistoryImportInspectionReceipt class final
- Inheritance
-
- Object
- EntityGraphDevtoolsHistoryImportInspectionResult
- EntityGraphDevtoolsHistoryImportInspectionReceipt
Constructors
-
EntityGraphDevtoolsHistoryImportInspectionReceipt({required String candidateId, required String storeId, required String inspectedAt, required int bytes, required Iterable<
EntityGraphDevtoolsHistoryImportSnapshotInspection> snapshots})
Properties
- bytes → int
-
final
- candidateId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inspectedAt → String
-
final
- protocolVersion → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
snapshots
→ List<
EntityGraphDevtoolsHistoryImportSnapshotInspection> -
final
- storeId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited