EntityGraphDevtoolsMutationEvent class final
- Inheritance
-
- Object
- EntityGraphDevtoolsEnvelope
- EntityGraphDevtoolsEvent
- EntityGraphDevtoolsMutationEvent
Constructors
-
EntityGraphDevtoolsMutationEvent({required String storeId, required int sequence, required String eventId, required String correlationId, required String observedAt, required EntityGraphDevtoolsSnapshotReference snapshot, required Iterable<
EntityGraphDevtoolsChange> changes, required Iterable<EntityGraphDevtoolsViewMembership> affectedEntities, required Iterable<String> affectedViewIds, required EntityGraphDevtoolsCounts before, required EntityGraphDevtoolsCounts after, required double projectionDurationMs, required bool valuesTruncated, required int changesOmitted})
Properties
-
affectedEntities
→ List<
EntityGraphDevtoolsViewMembership> -
final
-
affectedViewIds
→ List<
String> -
final
- after → EntityGraphDevtoolsCounts
-
final
- before → EntityGraphDevtoolsCounts
-
final
-
changes
→ List<
EntityGraphDevtoolsChange> -
final
- changesOmitted → int
-
final
- correlationId → String
-
finalinherited
- eventId → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- observedAt → String
-
finalinherited
- projectionDurationMs → double
-
final
- protocol → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequence → int
-
finalinherited
- snapshot → EntityGraphDevtoolsSnapshotReference
-
final
- storeId → String
-
finalinherited
- type → String
-
no setteroverride
- valuesTruncated → bool
-
final
- version → int
-
no setterinherited
Methods
-
envelopeJson(
) → Map< String, Object?> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
payloadJson(
) → Map< String, Object?> -
override
-
toJson(
) → Map< String, Object?> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited