EntityGraphDevtoolsPreviewRestoredReceipt class final
- Inheritance
-
- Object
- EntityGraphDevtoolsPreviewRestoreReceipt
- EntityGraphDevtoolsPreviewRestoredReceipt
Constructors
- EntityGraphDevtoolsPreviewRestoredReceipt({required String previewId, required Object? restoredPatch, required int observedRevision, required String restoredAt})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- observedRevision → int
-
final
- previewId → String
-
finalinherited
- restoredAt → String
-
final
- restoredPatch → Object?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited