EntityGraphDevtoolsSnapshot class final
Store-level metrics, active previews, and bounded-history status.
- Inheritance
-
- Object
- EntityGraphDevtoolsEnvelope
- EntityGraphDevtoolsSnapshot
Constructors
-
EntityGraphDevtoolsSnapshot({required String storeId, required String capturedAt, required EntityGraphDevtoolsCounts counts, required EntityGraphDevtoolsHistoryStatus history, required EntityGraphDevtoolsSnapshotHistoryStatus snapshots, required List<
EntityGraphDevtoolsActivePreview> activePreviews}) -
const
Properties
-
activePreviews
→ List<
EntityGraphDevtoolsActivePreview> -
final
- capturedAt → String
-
final
- counts → EntityGraphDevtoolsCounts
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- history → EntityGraphDevtoolsHistoryStatus
-
final
- protocol → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapshots → EntityGraphDevtoolsSnapshotHistoryStatus
-
final
- storeId → String
-
finalinherited
- version → int
-
no setterinherited
Methods
-
envelopeJson(
) → Map< String, Object?> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited