EntityGraphDevtoolsSnapshotHistoryStatus class final
Constructors
- EntityGraphDevtoolsSnapshotHistoryStatus({required EntityGraphDevtoolsHistoryMode mode, required int? cursor, required EntityGraphDevtoolsSnapshotSource? source, required int retainedSnapshots, required int retainedBytes, required int snapshotLimit, required int byteLimit, required int? baselineCursor, required int? oldestCursor, required int? newestCursor, required int? latestCursor, required EntityGraphDevtoolsImportCandidateStatus? importCandidate})
-
const
Properties
- baselineCursor → int?
-
final
- byteLimit → int
-
final
- cursor → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- importCandidate → EntityGraphDevtoolsImportCandidateStatus?
-
final
-
final
- latestCursor → int?
-
final
- mode → EntityGraphDevtoolsHistoryMode
-
final
- newestCursor → int?
-
final
- oldestCursor → int?
-
final
- retainedBytes → int
-
final
- retainedSnapshots → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapshotLimit → int
-
final
- source → EntityGraphDevtoolsSnapshotSource?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited