EntityGraphDevtoolsTimeTravelEvent class final
- Inheritance
-
- Object
- EntityGraphDevtoolsEnvelope
- EntityGraphDevtoolsEvent
- EntityGraphDevtoolsTimeTravelEvent
Constructors
- EntityGraphDevtoolsTimeTravelEvent({required String storeId, required int sequence, required String eventId, required String correlationId, required String observedAt, required EntityGraphDevtoolsHistoryMode state, required int? cursor, required int? previousCursor, required EntityGraphDevtoolsSnapshotSource? source, required EntityGraphDevtoolsSnapshotSource? previousSource, required EntityGraphDevtoolsTimeTravelReason reason})
-
const
Properties
- correlationId → String
-
finalinherited
- cursor → int?
-
final
- eventId → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- observedAt → String
-
finalinherited
- previousCursor → int?
-
final
- previousSource → EntityGraphDevtoolsSnapshotSource?
-
final
- protocol → String
-
no setterinherited
- reason → EntityGraphDevtoolsTimeTravelReason
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequence → int
-
finalinherited
- source → EntityGraphDevtoolsSnapshotSource?
-
final
- state → EntityGraphDevtoolsHistoryMode
-
final
- storeId → String
-
finalinherited
- type → String
-
no setteroverride
- version → int
-
no setterinherited
Methods
-
envelopeJson(
) → Map< String, Object?> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
payloadJson(
) → Map< String, Object?> -
override
-
toJson(
) → Map< String, Object?> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited