EntityGraphDevtoolsViewRecord class final
Constructors
-
EntityGraphDevtoolsViewRecord({required EntityGraphDevtoolsViewDefinition definition, required String registeredAt, required String? lastRenderedAt, required int renderCount, required int subscriberCount, required Iterable<
EntityGraphDevtoolsViewMembership> membership, required EntityGraphDevtoolsViewListStats? list})
Properties
- definition → EntityGraphDevtoolsViewDefinition
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastRenderedAt → String?
-
final
- list → EntityGraphDevtoolsViewListStats?
-
final
-
membership
→ List<
EntityGraphDevtoolsViewMembership> -
final
- registeredAt → String
-
final
- renderCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriberCount → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited